@@ -8,7 +8,7 @@ package inc::MBX::Alien::FLTK::Utility;
     use Cwd qw[];
     use Exporter qw[import];
     our @EXPORT_OK
-        = qw[can_run run _o _a _exe _dll _path _abs _rel _dir _file _split _cwd];
+        = qw[can_run run _o _a _exe _dll _path _realpath _abs _rel _dir _file _split _cwd];
 
     sub can_run {    # Snagged from IPC::CMD and trimmed for my use
         my ($prog) = @_;
@@ -21,11 +21,13 @@ package inc::MBX::Alien::FLTK::Utility;
             return $prog if scalar $syms->getsym(uc $prog);
         }
         require ExtUtils::MM;
+        my @possible;
         for my $dir ((split /\Q$Config{path_sep}\E/, $ENV{PATH}),
                      File::Spec->curdir)
         {   my $abs = File::Spec->catfile($dir, $prog);
-            return $abs if $abs = MM->maybe_command($abs);
+            push @possible, $abs if $abs = MM->maybe_command($abs);
         }
+        return wantarray ? @possible : $possible[0];
     }
     sub run { return !system(join ' ', @_); }
 
@@ -58,11 +60,15 @@ package inc::MBX::Alien::FLTK::Utility;
         $file =~ m[^(.*)(?:\..*)$] or return @_;
         return catpath($vol, $dir, ($1 ? $1 : $file) . '.' . $Config{'so'});
     }
-    sub _path  { File::Spec->catdir(@_) }
+    sub _path { File::Spec->catdir(@_) }
+
+    sub _realpath {
+        eval { Cwd::realpath(File::Spec->canonpath(shift)) };
+    }
     sub _abs   { File::Spec->rel2abs(@_) }
     sub _rel   { File::Spec->abs2rel(@_) }
-    sub _file  { File::Basename::basename(shift); }
-    sub _dir   { File::Basename::dirname(shift); }
+    sub _file  { File::Basename::basename(shift) }
+    sub _dir   { File::Basename::dirname(shift || '') }
     sub _split { File::Spec->splitpath(@_) }
     sub _cwd   { Cwd::cwd(); }
     1;
